.. _zephyr_general:

General information about the Zephyr port
=========================================

The Zephyr Project is a Linux Foundation hosted Collaboration Project. It’s an open
source collaborative effort uniting developers and users in building a
small, scalable, real-time operating system (RTOS) optimized for resource-constrained
devices, across multiple architectures.

Multitude of boards
-------------------

There is a multitude of modules and boards from different sources that are supported
by the Zephyr OS. All boards supported by Zephyr (with standard level of features
support, like UART console) should work with MicroPython (but not all were tested).
The FRDM-K64f board is taken as a reference board for the port for this documentation.
If you have another board, please make sure you have a datasheet, schematics and other
reference materials for your board handy to look up various aspects of your board
functioning.

For a full list of Zephyr supported boards click `here (external link) <https://docs.zephyrproject.org/latest/boards/index.html#boards>`_
